@@ -1,4 +1,4 @@
-use crate::{Auth, CommandOutput, ConfigFile, SshClient};
+use crate::{MasshConfig, SshAuth, SshClient, SshOutput};
 use anyhow::Result;
 use parking_lot::Mutex;
 use std::collections::HashMap;
@@ -7,10 +7,10 @@ use std::sync::mpsc::Receiver;
 use std::sync::Arc;
 use threadpool::ThreadPool;
 
-/// One of the configured hosts of a [`MasshClient`] represented as "username@ip-address:port".
+/// Unique string identifier (`username@ip_address:port`) for a `MasshClient` target host.
 pub type MasshHost = String;
 
-/// Receiving half of a [`std::sync::mpsc::channel`]. Exactly 1 message per host is received.
+/// Receiving half of a `std::sync::mpsc::channel` which receives exactly 1 message per host.
 pub type MasshReceiver<T> = Receiver<(MasshHost, Result<T>)>;
 
 /// SSH client to run commands on multiple hosts in parallel.
@@ -28,14 +28,14 @@ pub type MasshReceiver<T> = Receiver<(MasshHost, Result<T>)>;
 /// ## Example
 ///
 /// ```no_run
-/// use massh::{ConfigFile, MasshClient};
+/// use massh::{MasshClient, MasshConfig};
 ///
 /// // Construct a new `MasshClient` from a YAML configuration file.
 /// let yaml = std::fs::read_to_string("massh.yaml").unwrap();
-/// let config = ConfigFile::from_json(&yaml).unwrap();
+/// let config = MasshConfig::from_json(&yaml).unwrap();
 /// let massh = MasshClient::from(&config);
 ///
-/// // Run a command on all the configured host.
+/// // Run a command on all the configured hosts.
 /// let rx = massh.execute("docker ps");
 ///
 /// // Receive the result of the command for each host and print its output.
@@ -53,19 +53,19 @@ pub struct MasshClient {
 }
 
 impl MasshClient {
-    /// Constructs a new `MasshClient` from the specified configuration file.
+    /// Constructs a new `MasshClient` from the specified configuration.
     ///
-    /// See [`ConfigFile`] for more details.
+    /// See [`MasshConfig`] for more details.
     ///
     /// ## Example
     /// ```no_run
-    /// use massh::{ConfigFile, MasshClient};
+    /// use massh::{MasshClient, MasshConfig};
     ///
     /// let yaml = std::fs::read_to_string("massh.yaml").unwrap();
-    /// let config = ConfigFile::from_json(&yaml).unwrap();
+    /// let config = MasshConfig::from_json(&yaml).unwrap();
     /// let massh = MasshClient::from(&config);
     /// ```
-    pub fn from(config: &ConfigFile) -> Self {
+    pub fn from(config: &MasshConfig) -> Self {
         // Configure the internal SSH clients.
         let mut clients = HashMap::new();
         config.hosts.iter().for_each(|host| {
@@ -85,9 +85,9 @@ impl MasshClient {
 
             let mut ssh = SshClient::from(user, (addr, port));
             match auth {
-                Auth::Agent => ssh.set_auth_agent(),
-                Auth::Password(password) => ssh.set_auth_password(password),
-                Auth::Pubkey(path) => ssh.set_auth_pubkey(path),
+                SshAuth::Agent => ssh.set_auth_agent(),
+                SshAuth::Password(password) => ssh.set_auth_password(password),
+                SshAuth::Pubkey(path) => ssh.set_auth_pubkey(path),
             };
             ssh.set_timeout(config.timeout);
 
@@ -105,9 +105,9 @@ impl MasshClient {
         MasshClient { clients, pool }
     }
 
-    /// Attempts to execute a command on the configured hosts.
+    /// Attempts to execute a command on all configured hosts.
     ///
-    /// It returns a [`MasshReceiver`] that receives exactly 1 message per host.
+    /// It returns a [`MasshReceiver`] which receives exactly 1 message per host.
     /// Each message contains the result of the operation.
     ///
     /// ## Example
@@ -120,7 +120,7 @@ impl MasshClient {
     ///     println!("Command succeeded on {}? {}", host, result.is_ok());
     /// }
     /// ```
-    pub fn execute(&self, command: impl Into<String>) -> MasshReceiver<CommandOutput> {
+    pub fn execute(&self, command: impl Into<String>) -> MasshReceiver<SshOutput> {
         let command = command.into();
 
         // Create a multi-producer, single-consumer channel.
@@ -149,12 +149,12 @@ impl MasshClient {
         rx
     }
 
-    /// Attempts to download a file from the configured hosts.
+    /// Attempts to download a file from all configured hosts.
     ///
-    /// It returns a [`MasshReceiver`] that receives exactly 1 message per host.
+    /// It returns a [`MasshReceiver`] which receives exactly 1 message per host.
     /// Each message contains the result of the operation.
     ///
-    /// Note that the downloaded file names are of the form "user@ip-address:port".
+    /// Note that the downloaded filenames are of the form `username@ip_address:port`.
     ///
     /// ## Example
     /// ```no_run
@@ -199,9 +199,9 @@ impl MasshClient {
         rx
     }
 
-    /// Attempts to upload a file to the configured hosts.
+    /// Attempts to upload a file to all configured hosts.
     ///
-    /// It returns a [`MasshReceiver`] that receives exactly 1 message per host.
+    /// It returns a [`MasshReceiver`] which receives exactly 1 message per host.
     /// Each message contains the result of the operation.
     ///
     /// ## Example
